Format input
formatMatrixForCorrelation.RdThis function pastes the modality at the end of each feature ID and then combines the matrices into one matrix object. The matrices must have common sample IDs as the rownames to join by.
formatMatrixForCorrelation.RdThis function pastes the modality at the end of each feature ID and then combines the matrices into one matrix object. The matrices must have common sample IDs as the rownames to join by.