Example Peak Counts
peak_counts.RdA list of matrices containing VST transformed counts for multiple modalities to be integrated. The matrices include features (peaks) as rows and samples as columns. Each matrix contains a "sample_info" attribute that is a dataframe which provides metadata information to be used for data normalization. The rownames should be identical to the column names for the respective matrix. The dataframe should only include numeric and factor data.